Learn R Programming

icardaFIGSr (version 1.0.2)

durumDaily: durumDaily

Description

200 sites from durum wheat collection and their daily climatic data.

Usage

data(durumDaily)

Arguments

Format

The data includes the site unique identifier and daily data for 4 climatic variables (tmin, tmax, precipitation and relative humidity)

Examples

Run this code
# NOT RUN {
if(interactive()){
 # Load durum wheat data with their daily climatic variables obtained from ICARDA database
 data(durumDaily)
}
# }

Run the code above in your browser using DataLab