Learn R Programming

icardaFIGSr (version 1.0.2)

durumWC: durumWC

Description

200 sites from durum wheat collection and their world clim data.

Usage

data(durumWC)

Arguments

Format

The data includes the site unique identifier, longitude, latitude and 55 worldclim data worldclim

Examples

Run this code
# NOT RUN {
if(interactive()){
 # Load durum wheat data with world climatic variables obtained from WorldClim database
 data(durumWC)
 }
# }

Run the code above in your browser using DataLab