Learn R Programming

icardaFIGSr (version 1.0.2)

getCrops: Crops Available in ICARDA's Genebank

Description

this function allows to obtain a list of crops available in ICARDA's Genebank Documentation System, it returns a list with codes and names of available crops.

Usage

getCrops()

Arguments

Value

A list containing all crops available in ICARDA's Genebank Documentation System.

Details

The crop codes and names are fetched from ICARDA's online server.

Examples

Run this code
# NOT RUN {
if(interactive()){
 # Get list of available crops
 crops <- getCrops()
 }
# }

Run the code above in your browser using DataLab