Learn R Programming

icardaFIGSr (version 1.0.2)

getTraits: Getting Traits Associated with Crops from the ICARDA's Genebank Documentation System

Description

Return a data frame containing traits associated with a particular crop, their description and related identifiers.

Usage

getTraits(crop)

Arguments

crop

character. Crop for which to get available traits.

Value

A data frame with traits that are associated with the crop specified in crop.

Details

getTraits returns a data frame of traits together with their IDs and coding system used for each trait.

Possible inputs for crop include:

  • 'Aegilops'

  • 'Barley'

  • 'Bread wheat'

  • 'Chickpea'

  • 'Durum wheat'

  • 'Faba bean'

  • 'Faba bean BPL'

  • 'Forage and range'

  • 'Lathyrus'

  • 'Lentil'

  • 'Medicago annual'

  • 'Not mandate cereals'

  • 'Pisum'

  • 'Primitive wheat'

  • 'Trifolium'

  • 'Vicia'

  • 'Wheat hybrids'

  • 'Wheat wild relatives'

  • 'Wild Cicer'

  • 'Wild Hordeum'

  • 'Wild Lens'

  • 'Wild Triticum'

A list of available crops to use as input for crop can also be obtained from ICARDA's online server using getCrops.

Examples

Run this code
# NOT RUN {
if(interactive()){
 # Get traits for bread wheat
 breadTraits <- getTraits(crop = 'Bread wheat')
}
# }

Run the code above in your browser using DataLab