Learn R Programming

icardaFIGSr (version 1.0.2)

mapAccessions: Plotting Accessions on Map.

Description

this function returns a map with points showing where accessions are located.

Usage

mapAccessions(df, long, lat, y = NULL)

Arguments

df

object of class "data.frame" with coordinates of accessions and target variable.

long

character. Column name from df representing longitude.

lat

character. Column name from df representing latitude.

y

Default: NULL, column name from df representing the target variable.

Value

A world map with plotted points showing locations of accessions.

Examples

Run this code
# NOT RUN {
if(interactive()){
 # Loading FIGS subset for wheat sodicity resistance
 data(FIGS)
 # World Map showing locations of accessions
 mapAccessions(df = FIGS, long = "Longitude", lat = "Latitude")
 
 # Map plotting locations of accessions with points coloured 
 # based on a gradient scale of SodicityIndex values
 mapAccessions(FIGS, long = "Longitude", lat = "Latitude", 
               y = "SodicityIndex")
 # Map plotting locations of accessions with points
 # coloured based on levels of y 
 mapAccessions(FIGS, long = "Longitude", lat = "Latitude", 
 y = "PopulationType")
 }
# }

Run the code above in your browser using DataLab