powered by
200 sites from durum wheat collection and their daily climatic data.
data(durumDaily)
The data includes the site unique identifier and daily data for 4 climatic variables (tmin, tmax, precipitation and relative humidity)
# NOT RUN { if(interactive()){ # Load durum wheat data with their daily climatic variables obtained from ICARDA database data(durumDaily) } # }
Run the code above in your browser using DataLab