powered by
200 sites from durum wheat collection and their world clim data.
data(durumWC)
The data includes the site unique identifier, longitude, latitude and 55 worldclim data worldclim
# NOT RUN { if(interactive()){ # Load durum wheat data with world climatic variables obtained from WorldClim database data(durumWC) } # }
Run the code above in your browser using DataLab