Learn R Programming

icardaFIGSr (version 1.0.2)

getAccessions: Getting Accession Data from ICARDA's Genebank Documentation System

Description

Return a data frame with accession data for the specified crop.

Usage

getAccessions(
  crop = "",
  ori = NULL,
  IG = "",
  doi = FALSE,
  taxon = FALSE,
  collectionYear = FALSE,
  coor = FALSE,
  available = FALSE
)

Arguments

crop

character. Crop for which to get accession data. See section 'Details' for available crops or use getCrops function. Default: "".

ori

string. Country of origin using the ISO 3166-1 alpha-3 country codes. Default: NULL.

IG

integer. Unique identifier of accession. Default: "".

doi

boolean. If TRUE , the function will return the digital object identifiers DOI for the accessions. Default: FALSE.

taxon

boolean. If TRUE, the function will return the taxon information of the accessions. Default: FALSE.

collectionYear

boolean. If TRUE, the function will return the year of the collecting mission. Default: FALSE.

coor

boolean. If TRUE, returns only georeferenced accessions containing longitude and latitude. Default: FALSE.

available

boolean. If TRUE, returns the availability of accessions for distribution, Default: FALSE.

Value

A data frame with accession passport data for specified crop in crop from the locations in ori.

Details

Types of crops available include:

  • 'Aegilops'

  • 'Barley'

  • 'Bread wheat'

  • 'Chickpea'

  • 'Durum wheat'

  • 'Faba bean'

  • 'Faba bean BPL'

  • 'Forage and range'

  • 'Lathyrus'

  • 'Lentil'

  • 'Medicago annual'

  • 'Not mandate cereals'

  • 'Pisum'

  • 'Primitive wheat'

  • 'Trifolium'

  • 'Vicia'

  • 'Wheat hybrids'

  • 'Wheat wild relatives'

  • 'Wild Cicer'

  • 'Wild Hordeum'

  • 'Wild Lens'

  • 'Wild Triticum'

Alternatively, the list of available crops can be fetched from ICARDA's online server using getCrops.

Examples

Run this code
# NOT RUN {
if(interactive()){
 # Obtain accession data for durum wheat
 durum <- getAccessions(crop = 'Durum wheat', coor = TRUE)
}
# }

Run the code above in your browser using DataLab