powered by
Return a data frame with accession data for the specified crop.
getAccessions( crop = "", ori = NULL, IG = "", doi = FALSE, taxon = FALSE, collectionYear = FALSE, coor = FALSE, available = FALSE )
character. Crop for which to get accession data. See section 'Details' for available crops or use getCrops function. Default: "".
getCrops
string. Country of origin using the ISO 3166-1 alpha-3 country codes. Default: NULL.
integer. Unique identifier of accession. Default: "".
boolean. If TRUE , the function will return the digital object identifiers DOI for the accessions. Default: FALSE.
TRUE
boolean. If TRUE, the function will return the taxon information of the accessions. Default: FALSE.
boolean. If TRUE, the function will return the year of the collecting mission. Default: FALSE.
boolean. If TRUE, returns only georeferenced accessions containing longitude and latitude. Default: FALSE.
boolean. If TRUE, returns the availability of accessions for distribution, Default: FALSE.
A data frame with accession passport data for specified crop in crop from the locations in ori.
crop
ori
Types of crops available include:
'Aegilops'
'Barley'
'Bread wheat'
'Chickpea'
'Durum wheat'
'Faba bean'
'Faba bean BPL'
'Forage and range'
'Lathyrus'
'Lentil'
'Medicago annual'
'Not mandate cereals'
'Pisum'
'Primitive wheat'
'Trifolium'
'Vicia'
'Wheat hybrids'
'Wheat wild relatives'
'Wild Cicer'
'Wild Hordeum'
'Wild Lens'
'Wild Triticum'
Alternatively, the list of available crops can be fetched from ICARDA's online server using getCrops.
# NOT RUN { if(interactive()){ # Obtain accession data for durum wheat durum <- getAccessions(crop = 'Durum wheat', coor = TRUE) } # }
Run the code above in your browser using DataLab