this function allows to obtain a list of crops available in ICARDA's Genebank Documentation System, it returns a list with codes and names of available crops.
Usage
getCrops()
Arguments
Value
A list containing all crops available in ICARDA's Genebank Documentation System.
Details
The crop codes and names are fetched from ICARDA's online server.