# NOT RUN {
if(interactive()){
# Extract onset data for durum wheat
durum <- getAccessions(crop = 'Durum wheat', coor = TRUE)
onset <- getOnset(sites = levels(as.factor(durum$SiteCode)), crop = 'ICDW',
var = c('tavg', 'prec', 'rh'), cv = TRUE)
# Get data frame with climatic variables from list object returned
onset.clim <- onset[[1]]
# Get data frame with coefficient of variation from list object
# returned (when cv = TRUE)
onset.cv <- onset[[2]]
# Get data frame with phenotypic variables from list object returned
onset.pheno <- onset[[3]]
}
# }
Run the code above in your browser using DataLab