getTraits returns a data frame of traits together with their IDs and coding system used for each trait.
Possible inputs for crop include:
'Aegilops'
'Barley'
'Bread wheat'
'Chickpea'
'Durum wheat'
'Faba bean'
'Faba bean BPL'
'Forage and range'
'Lathyrus'
'Lentil'
'Medicago annual'
'Not mandate cereals'
'Pisum'
'Primitive wheat'
'Trifolium'
'Vicia'
'Wheat hybrids'
'Wheat wild relatives'
'Wild Cicer'
'Wild Hordeum'
'Wild Lens'
'Wild Triticum'
A list of available crops to use as input for crop can also be obtained from ICARDA's online server using getCrops.